@@ -3,7 +3,7 @@
 # File      : Segment.pm
 # Author    : Duco Dokter
 # Created   : Tue Mar  4 13:03:00 2003
-# Version   : $Id: Segment.pm,v 1.4 2003/07/18 07:44:24 wyldebeast Exp $ 
+# Version   : $Id: Segment.pm,v 1.7 2003/11/25 13:33:30 wyldebeast Exp $ 
 # Copyright : Wyldebeast & Wunderliebe
 #
 ################################################################################
@@ -12,8 +12,11 @@ package Net::HL7::Segment;
 
 use 5.004;
 use strict;
+use Net::HL7::Segments::MSH;
+
 
 our $FIELD_SEPARATOR = "|";
+our $NULL = "\"\"";
 
 =pod
 
@@ -50,7 +53,7 @@ sub new {
     my $class = shift;
     bless my $self = {}, $class;
     
-    $self->_init(@_) || return 0;
+    $self->_init(@_) || return undef;
     
     return $self;
 }
@@ -60,32 +63,53 @@ sub _init {
     
     my ($self, $name) = @_;
 
-    (length($name) == 3) || return undef;
+    ($name && (length($name) == 3)) || return undef;
     (uc($name) eq $name) || return undef;
 
+    $self->{FIELDS} = [];
+
     $self->{FIELDS}->[0] = $name;
 }
 
 
-=item setField($index, $value)
+=pod
+
+=item setField($index, @value)
 
 Set the field specified by index to value. Indices start at 1, to stay
 with the HL7 standard. Trying to set the value at index 0 has no
-effect;
+effect. If you provide more than one value, or an array of values, the
+field will effectively be set to the join of these fields with the
+Net::HL7::Segments::MSH::COMPONENT_SEPARATOR.  To set a field to the
+HL7 null value, instead of omitting a field, can be achieved with the
+Net::HL7::Segment::NULL variable, like:
+
+  $segment->setField(8, $Net::HL7::Segment::NULL);
+
+This will render the field as the double quote ("").
 
 =cut
 sub setField {
 
-    my ($self, $index, $value) = @_;
+    my ($self, $index, @value) = @_;
 
-    $index && ($self->{FIELDS}->[$index] = $value);
+    for (my $i = @{ $self->{FIELDS} }; $i < $index ; $i++) {
+	$self->{FIELDS}->[$i] = "";
+    }
+
+    $index && ($self->{FIELDS}->[$index] = 
+	       join($Net::HL7::Segments::MSH::COMPONENT_SEPARATOR, @value) );
 }
 
 
+=pod
 
 =item getField($index)
 
-Get the field at index.
+Get the field at index. If the field is a composed field, you will
+need to do something like:
+
+@values = split($Net::HL7::Segments::MSH::REPETITION_SEPARATOR, $segment->getField(9));
 
 =cut
 sub getField {
@@ -96,6 +120,41 @@ sub getField {
 }    
 
 
+=pod
+
+=item size()
+
+Get the number of fields for this segment, not including the name
+
+=cut
+sub size {
+
+    my $self = shift;
+
+    return @{ $self->{FIELDS} } - 1;
+}
+
+
+=pod
+
+=item getFields($from, $to)
+
+Get the fields in the specified range.
+
+=cut
+sub getFields {
+
+    my ($self, $from, $to) = @_;
+
+    $from || ($from = 0);
+    $to || ($to = $#{$self->{FIELDS}});
+
+    return @{ $self->{FIELDS} }[$from..$to];
+}    
+
+
+=pod 
+
 =item getName()
 
 Get the name of the segment. This is basically the value at index 0
@@ -109,6 +168,8 @@ sub getName {
 }
 
 
+=pod
+
 =item setFieldSeparator($sep)
 
 Set the field separator for the segment
@@ -122,6 +183,8 @@ sub setFieldSeparator {
 }
 
 
+=pod
+
 =item getFieldSeparator()
 
 Get the field separator for the segment
@@ -135,10 +198,13 @@ sub getFieldSeparator {
 }
 
 
+=pod
+
 =item toString()
 
 Return a string representation of this segment, based on the
-L<Net::HL7::Segment::FIELD_SEPARATOR> variable.  
+L<Net::HL7::Segment::FIELD_SEPARATOR> variable. This method renders a
+syntactically correct segment representation.
 
 =back
 
@@ -146,12 +212,15 @@ L<Net::HL7::Segment::FIELD_SEPARATOR> variable.
 sub toString {
 
     my $self = shift;
-    
+
     return join($FIELD_SEPARATOR, @{ $self->{FIELDS} });
 }
 
 1;
 
+
+=pod
+
 =head1 AUTHOR
 
 D.A.Dokter <dokter@wyldebeast-wunderliebe.com>
